/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 10/06/2023
 */

#include "event.h"

namespace vampiria { namespace event {

UI::UI(event::Manager *manager)
{
    vmp::except_check_pointer((void *)manager,"event0::UI::UI() null input Manager");
    manager_=manager;
}

UI::~UI()
{
    manager_=0;
}

event::Manager *UI::manager()
{
    return manager_;
}

event::Event *UI::child_event_new(event::Cell *cell)
{
    return 0;
}

vmp::str UI::identity(event::Cell *cell)
{
    return "";
}

}}

